@@ -1,10 +1,10 @@
 package Test::Core;
-$Test::Core::VERSION = '0.0101';
+$Test::Core::VERSION = '0.0200';
 use Data::Dump                  ();
 use Import::Into;
 use Module::Load                ();
-use Sub::Override               ();
 use Test::Modern                ();
+use Test::MockModule            ();
 use Test::MockObject            ();
 use Test::MockObject::Extends   ();
 
@@ -20,10 +20,10 @@ sub import {
 
 sub mock_module {
     my ($class, %mocks) = @_;
-    my $mock_module = Sub::Override->new;
+    my $mock_module = Test::MockModule->new($class);
     while (my ($method, $override) = each(%mocks)) {
-        $mock_module->replace(
-            ($class . '::' . $method),
+        $mock_module->mock(
+            $method,
             ('CODE' eq ref $override ? $override : sub { $override })
         );
     }
@@ -61,7 +61,7 @@ Test::Core - Modern Perl testing with a single import
 
 =head1 VERSION
 
-version 0.0101
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -273,7 +273,7 @@ Test::Core exports the following from L<Data::Dump>:
 
 =head2 Test::Core
 
-Test::Core implements the following mocking functions using L<Sub::Override>, L<Test::MockObject>, and L<Test::MockObject::Extends>:
+Test::Core implements the following mocking functions using L<Test::MockModule>, L<Test::MockObject>, and L<Test::MockObject::Extends>:
 
 =over 4
 
